<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT">
<context>
    <name>AboutDialog</name>
    <message>
        <source>$TRANSLATION_AUTHOR</source>
        <translation type="obsolete">Diego Pierotto</translation>
    </message>
    <message>
        <source>$TRANSLATION_AUTHOR_EMAIL</source>
        <comment>Here you can enter your email or homepage if you want.</comment>
        <translation type="obsolete">ita.translations@tiscali.it</translation>
    </message>
    <message>
        <source>Information on how to translate KeePassX can be found under:</source>
        <translation>Informazioni su come tradurre KeePassX si possono trovare qui:</translation>
    </message>
    <message>
        <source>Team</source>
        <translation>Gruppo</translation>
    </message>
    <message>
        <source>Developer, Project Admin</source>
        <translation>Sviluppatore, Amministratore progetto</translation>
    </message>
    <message>
        <source>Web Designer</source>
        <translation>Disegnatore Web</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Sviluppatore</translation>
    </message>
    <message>
        <source>Thanks To</source>
        <translation>Ringraziamenti</translation>
    </message>
    <message>
        <source>Patches for better MacOS X support</source>
        <translation>Patches per migliorie a MacOS X</translation>
    </message>
    <message>
        <source>Main Application Icon</source>
        <translation>Icona applicazione principale</translation>
    </message>
    <message>
        <source>Various fixes and improvements</source>
        <translation>Alcune correzioni e migliorie</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>File &apos;%1&apos; could not be found.</source>
        <translation>Impossibile trovare il file &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Make sure that the program is installed correctly.</source>
        <translation>Assicurati che il programma sia installato correttamente.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Current Translation</source>
        <translation>Traduzione attuale</translation>
    </message>
    <message>
        <source>None</source>
        <comment>Please replace &apos;None&apos; with the language of your translation</comment>
        <translation>Italiano</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autore</translation>
    </message>
</context>
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>Informazioni su</translation>
    </message>
    <message>
        <source>AppName</source>
        <translation>AppName</translation>
    </message>
    <message>
        <source>AppFunc</source>
        <translation>AppFunc</translation>
    </message>
    <message>
        <source>http://keepassx.sourceforge.net</source>
        <translation>http://keepassx.sourceforge.net</translation>
    </message>
    <message>
        <source>keepassx@gmail.com</source>
        <translation>keepassx@gmail.com</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation>Crediti</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation>Traduzione</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <source>Copyright (C) 2005 - 2008 KeePassX Team 
KeePassX is distributed under the terms of the 
General Public License (GPL) version 2.</source>
        <translation type="obsolete">Copyright (C) 2005 - 2008 KeePassX Team
KeePassX è distribuito sotto i termini della 
General Public License (GPL) versione 2.</translation>
    </message>
    <message>
        <source>Copyright (C) 2005 - 2009 KeePassX Team 
KeePassX is distributed under the terms of the 
General Public License (GPL) version 2.</source>
        <translation type="obsolete">Copyright (C) 2005 - 2008 KeePassX Team
KeePassX è distribuito sotto i termini della 
General Public License (GPL) versione 2. {2005 ?} {2009 ?} {2.?}</translation>
    </message>
    <message>
        <source>Copyright (C) 2005 - 2009 KeePassX Team
KeePassX is distributed under the terms of the
General Public License (GPL) version 2.</source>
        <translation>Copyright (C) 2005 - 2009 KeePassX Team
KeePassX è distribuito sotto i termini della 
General Public License (GPL) versione 2.</translation>
    </message>
</context>
<context>
    <name>AddBookmarkDlg</name>
    <message>
        <source>Add Bookmark</source>
        <translation>Aggiungi ai Segnalibri</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Titolo:</translation>
    </message>
    <message>
        <source>File:</source>
        <translation>File:</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Sfoglia...</translation>
    </message>
    <message>
        <source>Edit Bookmark</source>
        <translation>Modifica i Segnalibri</translation>
    </message>
    <message>
        <source>KeePass Databases (*.kdb)</source>
        <translation>Database KeePass (*.kdb)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Tutti i files (*)</translation>
    </message>
</context>
<context>
    <name>AutoType</name>
    <message>
        <source>More than one &apos;Auto-Type:&apos; key sequence found.
Allowed is only one per entry.</source>
        <translation type="obsolete">Trovate più di una sequenza chiave di &apos;Auto Digitazione:&apos;.
E&apos; permessa solo una per voce.</translation>
    </message>
    <message>
        <source>Syntax Error in Auto-Type sequence near character %1
						Found &apos;{&apos; without closing &apos;}&apos;</source>
        <translation type="obsolete">Errore sintassi nella sequenza Auto Digitazione vicina al carattere %1
	Trovati &apos;{&apos; senza chiusura &apos;}&apos;</translation>
    </message>
    <message>
        <source>Auto-Type string contains invalid characters</source>
        <translation type="obsolete">La stringa di Auto Digitazione contiene caratteri non validi</translation>
    </message>
</context>
<context>
    <name>AutoTypeDlg</name>
    <message>
        <source>KeePassX - Auto-Type</source>
        <translation>KeePassX - Auto Digitazione</translation>
    </message>
    <message>
        <source>Click on an entry to auto-type it.</source>
        <translation>Clicca su una voce per Auto digitarlo.</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Gruppo</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome utente</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>Auto Digitazione</translation>
    </message>
</context>
<context>
    <name>CDbSettingsDlg</name>
    <message>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <source>AES(Rijndael):  256 Bit   (default)</source>
        <translation>AES(Rijndael):  256 Bit   (predefinito)</translation>
    </message>
    <message>
        <source>Twofish:  256 Bit</source>
        <translation>Twofish:  256 Bit</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Attenzione</translation>
    </message>
    <message>
        <source>Please determine the number of encryption rounds.</source>
        <translation>Determina il numero di passaggi di cifratura.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is not valid integer value.</source>
        <translation>&apos;%1&apos; non è un valore integer valido.</translation>
    </message>
    <message>
        <source>The number of encryption rounds have to be greater than 0.</source>
        <translation>Il numero di passaggi di cifratura deve essere maggiore di 0.</translation>
    </message>
</context>
<context>
    <name>CEditEntryDlg</name>
    <message>
        <source>Today</source>
        <translation>Oggi</translation>
    </message>
    <message>
        <source>1 Week</source>
        <translation>1 Settimana</translation>
    </message>
    <message>
        <source>2 Weeks</source>
        <translation>2 Settimane</translation>
    </message>
    <message>
        <source>3 Weeks</source>
        <translation>3 Settimane</translation>
    </message>
    <message>
        <source>1 Month</source>
        <translation>1 Mese</translation>
    </message>
    <message>
        <source>3 Months</source>
        <translation>3 Mesi</translation>
    </message>
    <message>
        <source>6 Months</source>
        <translation>6 Mesi</translation>
    </message>
    <message>
        <source>1 Year</source>
        <translation>1 Anno</translation>
    </message>
    <message>
        <source>Calendar...</source>
        <translation>Calendario...</translation>
    </message>
    <message>
        <source>%1 Bit</source>
        <translation>%1 Bit</translation>
    </message>
    <message>
        <source>Edit Entry</source>
        <translation>Modifica voce</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Attenzione</translation>
    </message>
    <message>
        <source>Password and password repetition are not equal.
Please check your input.</source>
        <translation>La password e la conferma password non sono uguali.
Verifica i valori inseriti.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>[Untitled Entry]</source>
        <translation>[Voce senza titolo]</translation>
    </message>
    <message>
        <source>Add Attachment...</source>
        <translation>Aggiungi allegato...</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>Could not open file.</source>
        <translation>Impossibile aprire il file.</translation>
    </message>
    <message>
        <source>The chosen entry has no attachment or it is empty.</source>
        <translation>La voce scelta non ha allegati oppure è vuota.</translation>
    </message>
    <message>
        <source>Save Attachment...</source>
        <translation>Salva allegato...</translation>
    </message>
    <message>
        <source>Error while writing the file.</source>
        <translation>Errore durante la scrittura del file.</translation>
    </message>
    <message>
        <source>Delete Attachment?</source>
        <translation>Eliminare allegato?</translation>
    </message>
    <message>
        <source>You are about to delete the attachment of this entry.
Are you sure?</source>
        <translation>Stai per eliminare l&apos;allegato di questa voce.
Sei sicuro?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sì</translation>
    </message>
    <message>
        <source>No, Cancel</source>
        <translation>No, Annulla</translation>
    </message>
    <message>
        <source>New Entry</source>
        <translation>Nuova voce</translation>
    </message>
</context>
<context>
    <name>CGenPwDialog</name>
    <message>
        <source>Password Generator</source>
        <translation>Generatore di password</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation type="obsolete">Avviso</translation>
    </message>
    <message>
        <source>You need to enter at least one character</source>
        <translation type="obsolete">Devi inserire almeno un carattere</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">OK</translation>
    </message>
    <message>
        <source>%1 Bits</source>
        <translation>%1 Bits</translation>
    </message>
</context>
<context>
    <name>CSelectIconDlg</name>
    <message>
        <source>Replace...</source>
        <translation>Sostituisci...</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Add Custom Icon</source>
        <translation>Aggiungi icona personalizzata</translation>
    </message>
    <message>
        <source>Pick</source>
        <translation>Seleziona</translation>
    </message>
    <message>
        <source>Add Icons...</source>
        <translation>Aggiungi icone...</translation>
    </message>
    <message>
        <source>Images (%1)</source>
        <translation>Immagini (%1)</translation>
    </message>
    <message>
        <source>%1: File could not be loaded.</source>
        <translation>%1: Impossibile caricare il file.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>An error occured while loading the icon(s):</source>
        <translation>Errore durante il caricamento dell&apos;icona(e):</translation>
    </message>
    <message>
        <source>An error occured while loading the icon.</source>
        <translation>Errore durante il caricamento dell&apos;icona.</translation>
    </message>
</context>
<context>
    <name>CSettingsDlg</name>
    <message>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <source>Select a directory...</source>
        <translation>Seleziona una directory...</translation>
    </message>
    <message>
        <source>Select an executable...</source>
        <translation>Seleziona un eseguibile...</translation>
    </message>
    <message>
        <source>System Language</source>
        <translation>Lingua di sistema</translation>
    </message>
</context>
<context>
    <name>CalendarDialog</name>
    <message>
        <source>Calendar</source>
        <translation>Calendario</translation>
    </message>
</context>
<context>
    <name>CollectEntropyDlg</name>
    <message>
        <source>Random Number Generator</source>
        <translation>Generatore numero casuale</translation>
    </message>
    <message>
        <source>Collecting entropy...
Please move the mouse and/or press some keys until enought entropy for a reseed of the random number generator is collected.</source>
        <translation>Impostazione entropia...
Sposta il mouse e/o premi alcuni tasti finché ci sia sufficiente entropia affinché il generatore imposti un numero casuale.</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Verdana&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600; color:#006400;&quot;&gt;Random pool successfully reseeded!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Verdana&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600; color:#006400;&quot;&gt;Insieme casuale generato correttamente!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Entropy Collection</source>
        <translation>Accumulazione entropia</translation>
    </message>
</context>
<context>
    <name>CustomizeDetailViewDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Finestra di dialogo</translation>
    </message>
    <message>
        <source>Rich Text Editor</source>
        <translation>Editor Rich Text</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Grassetto</translation>
    </message>
    <message>
        <source>B</source>
        <translation>G</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Corsivo</translation>
    </message>
    <message>
        <source>I</source>
        <translation>C</translation>
    </message>
    <message>
        <source>Underlined</source>
        <translation>Sottolineato</translation>
    </message>
    <message>
        <source>U</source>
        <translation>S</translation>
    </message>
    <message>
        <source>Left-Aligned</source>
        <translation>Allineato a sinistra</translation>
    </message>
    <message>
        <source>L</source>
        <translation>S</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Centrato</translation>
    </message>
    <message>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <source>Right-Aligned</source>
        <translation>Allineato a destra</translation>
    </message>
    <message>
        <source>R</source>
        <translation>D</translation>
    </message>
    <message>
        <source>Justified</source>
        <translation>Giustificato</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Colore testo</translation>
    </message>
    <message>
        <source>Font Size</source>
        <translation>Dimensione carattere</translation>
    </message>
    <message>
        <source>6</source>
        <translation>6</translation>
    </message>
    <message>
        <source>7</source>
        <translation>7</translation>
    </message>
    <message>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <source>9</source>
        <translation>9</translation>
    </message>
    <message>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <source>11</source>
        <translation>11</translation>
    </message>
    <message>
        <source>12</source>
        <translation>12</translation>
    </message>
    <message>
        <source>14</source>
        <translation>14</translation>
    </message>
    <message>
        <source>16</source>
        <translation>16</translation>
    </message>
    <message>
        <source>18</source>
        <translation>18</translation>
    </message>
    <message>
        <source>20</source>
        <translation>20</translation>
    </message>
    <message>
        <source>22</source>
        <translation>22</translation>
    </message>
    <message>
        <source>24</source>
        <translation>24</translation>
    </message>
    <message>
        <source>26</source>
        <translation>26</translation>
    </message>
    <message>
        <source>28</source>
        <translation>28</translation>
    </message>
    <message>
        <source>36</source>
        <translation>36</translation>
    </message>
    <message>
        <source>42</source>
        <translation>42</translation>
    </message>
    <message>
        <source>78</source>
        <translation>78</translation>
    </message>
    <message>
        <source>Templates</source>
        <translation>Modelli</translation>
    </message>
    <message>
        <source>T</source>
        <translation>M</translation>
    </message>
    <message>
        <source>HTML</source>
        <translation>HTML</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Gruppo</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome utente</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Commento</translation>
    </message>
    <message>
        <source>Attachment Name</source>
        <translation>Nome allegato</translation>
    </message>
    <message>
        <source>Creation Date</source>
        <translation>Data creazione</translation>
    </message>
    <message>
        <source>Last Access Date</source>
        <translation>Data ultimo accesso</translation>
    </message>
    <message>
        <source>Last Modification Date</source>
        <translation>Data ultima modifica</translation>
    </message>
    <message>
        <source>Expiration Date</source>
        <translation>Data scadenza</translation>
    </message>
    <message>
        <source>Time till Expiration</source>
        <translation>Tempo fino alla scadenza</translation>
    </message>
</context>
<context>
    <name>Database</name>
    <message>
        <source>Never</source>
        <translation>Mai</translation>
    </message>
</context>
<context>
    <name>DatabaseSettingsDlg</name>
    <message>
        <source>Database Settings</source>
        <translation>Impostazioni Database</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Cifratura</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritmo:</translation>
    </message>
    <message>
        <source>Encryption Rounds:</source>
        <translation>Passaggi di cifratura:</translation>
    </message>
    <message>
        <source>Calculate rounds for a 1-second delay on this computer</source>
        <translation>Calcola passaggi con ritardo di un secondo su questo computer</translation>
    </message>
</context>
<context>
    <name>DetailViewTemplate</name>
    <message>
        <source>Group</source>
        <translation>Gruppo</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome utente</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Creation</source>
        <translation>Creazione</translation>
    </message>
    <message>
        <source>Last Access</source>
        <translation>Ultimo accesso</translation>
    </message>
    <message>
        <source>Last Modification</source>
        <translation>Ultima modifica</translation>
    </message>
    <message>
        <source>Expiration</source>
        <translation>Scadenza</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Commento</translation>
    </message>
</context>
<context>
    <name>EditEntryDialog</name>
    <message>
        <source>Edit Entry</source>
        <translation>Modifica voce</translation>
    </message>
    <message>
        <source>Ge&amp;n.</source>
        <translation>Ge&amp;n.</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Qualità:</translation>
    </message>
    <message>
        <source>Attachment:</source>
        <translation>Allegato:</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Titolo:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nome utente:</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Commento:</translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Gruppo:</translation>
    </message>
    <message>
        <source>Password Repet.:</source>
        <translation type="obsolete">Ripetizione password:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Password:</translation>
    </message>
    <message>
        <source>Expires:</source>
        <translation>Scade:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Mai</translation>
    </message>
    <message>
        <source>%1 Bit</source>
        <translation>%1 Bit</translation>
    </message>
    <message>
        <source>Icon:</source>
        <translation>Icona:</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation>Ripeti:</translation>
    </message>
</context>
<context>
    <name>EditGroupDialog</name>
    <message>
        <source>Group Properties</source>
        <translation>Proprietà gruppo</translation>
    </message>
    <message>
        <source>Icon:</source>
        <translation>Icona:</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Titolo:</translation>
    </message>
    <message>
        <source>&gt;</source>
        <translation>&gt;</translation>
    </message>
</context>
<context>
    <name>ExpiredEntriesDialog</name>
    <message>
        <source>Expired Entries</source>
        <translation>Voce scaduta</translation>
    </message>
    <message>
        <source>Double click on an entry to jump to it.</source>
        <translation>Doppio click sulla voce per aprirla.</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Gruppo</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome utente</translation>
    </message>
    <message>
        <source>Expired</source>
        <translation>Scaduta</translation>
    </message>
    <message>
        <source>Expired Entries in the Database</source>
        <translation>Voci scadute nel Database</translation>
    </message>
</context>
<context>
    <name>Export_KeePassX_Xml</name>
    <message>
        <source>KeePassX XML File</source>
        <translation>File XML KeePassX</translation>
    </message>
    <message>
        <source>XML Files (*.xml)</source>
        <translation>Files XML (*.xml)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Tutti i files (*)</translation>
    </message>
</context>
<context>
    <name>Export_Txt</name>
    <message>
        <source>Text File</source>
        <translation>File di testo</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Tutti i files (*)</translation>
    </message>
    <message>
        <source>Text Files (*.txt)</source>
        <translation>File di testo (*.txt)</translation>
    </message>
</context>
<context>
    <name>ExporterBase</name>
    <message>
        <source>Import File...</source>
        <translation type="obsolete">Importa file...</translation>
    </message>
    <message>
        <source>Export Failed</source>
        <translation>Esportazione fallita</translation>
    </message>
    <message>
        <source>Export File...</source>
        <translation>Esporta file...</translation>
    </message>
</context>
<context>
    <name>FileErrors</name>
    <message>
        <source>No error occurred.</source>
        <translation>Non si è verificato alcun errore.</translation>
    </message>
    <message>
        <source>An error occurred while reading from the file.</source>
        <translation>Si è verificato un errore durante la lettura del file.</translation>
    </message>
    <message>
        <source>An error occurred while writing to the file.</source>
        <translation>Si è verificato un errore durante la scrittura del file.</translation>
    </message>
    <message>
        <source>A fatal error occurred.</source>
        <translation>Si è verificato un errore fatale.</translation>
    </message>
    <message>
        <source>An resource error occurred.</source>
        <translation>Si è verificato un errore di risorsa.</translation>
    </message>
    <message>
        <source>The file could not be opened.</source>
        <translation>Impossibile aprire il file.</translation>
    </message>
    <message>
        <source>The operation was aborted.</source>
        <translation>L&apos;operazione è stata terminata.</translation>
    </message>
    <message>
        <source>A timeout occurred.</source>
        <translation>Si è verificata una scadenza.</translation>
    </message>
    <message>
        <source>An unspecified error occurred.</source>
        <translation>Si è verificato un errore non specificato.</translation>
    </message>
    <message>
        <source>The file could not be removed.</source>
        <translation>Impossibile rimuovere il file.</translation>
    </message>
    <message>
        <source>The file could not be renamed.</source>
        <translation>Impossibile rinominare il file.</translation>
    </message>
    <message>
        <source>The position in the file could not be changed.</source>
        <translation>La posizione nel file non può essere modificata.</translation>
    </message>
    <message>
        <source>The file could not be resized.</source>
        <translation>Impossibile ridimensionare il file.</translation>
    </message>
    <message>
        <source>The file could not be accessed.</source>
        <translation>Impossibile accedere al file.</translation>
    </message>
    <message>
        <source>The file could not be copied.</source>
        <translation>Impossibile copiare il file.</translation>
    </message>
</context>
<context>
    <name>GenPwDlg</name>
    <message>
        <source>Password Generator</source>
        <translation>Generatore di password</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <source>Use follo&amp;wing character groups:</source>
        <translation type="obsolete">Utilizza i se&amp;guenti gruppi di carattere:</translation>
    </message>
    <message>
        <source>Alt+W</source>
        <translation type="obsolete">Alt+G</translation>
    </message>
    <message>
        <source>&amp;Lower Letters</source>
        <translation>Lettere M&amp;inuscole</translation>
    </message>
    <message>
        <source>Alt+L</source>
        <translation type="obsolete">Alt+I</translation>
    </message>
    <message>
        <source>U&amp;nderline</source>
        <translation type="obsolete">So&amp;ttolineato</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="obsolete">Alt+T</translation>
    </message>
    <message>
        <source>&amp;Numbers</source>
        <translation>&amp;Numeri</translation>
    </message>
    <message>
        <source>White &amp;Spaces</source>
        <translation type="obsolete">&amp;Spazi vuoti</translation>
    </message>
    <message>
        <source>Alt+S</source>
        <translation type="obsolete">Alt+S</translation>
    </message>
    <message>
        <source>&amp;Upper Letters</source>
        <translation>Lettere M&amp;aiuscole</translation>
    </message>
    <message>
        <source>Alt+U</source>
        <translation type="obsolete">Alt+A</translation>
    </message>
    <message>
        <source>Minus</source>
        <translation type="obsolete">Meno</translation>
    </message>
    <message>
        <source>&amp;Special Characters</source>
        <translation>Caratteri &amp;Speciali</translation>
    </message>
    <message>
        <source>Use &amp;only following characters:</source>
        <translation type="obsolete">Utilizza s&amp;olo i seguenti caratteri:</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="obsolete">Alt+O</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Lunghezza:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Qualità:</translation>
    </message>
    <message>
        <source>Enable entropy collection</source>
        <translation>Abilita accumulazione entropia</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation type="obsolete">Alt+M</translation>
    </message>
    <message>
        <source>Collect only once per session</source>
        <translation>Imposta solo una volta per sessione</translation>
    </message>
    <message>
        <source>New Password:</source>
        <translation>Nuova password:</translation>
    </message>
    <message>
        <source>Generate</source>
        <translation>Genera</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Casuale</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Sottolinea</translation>
    </message>
    <message>
        <source>&amp;White Spaces</source>
        <translation>S&amp;pazi bianchi</translation>
    </message>
    <message>
        <source>&amp;Minus</source>
        <translation>&amp;Meno</translation>
    </message>
    <message>
        <source>Exclude look-alike characters</source>
        <translation>Escludi caratteri identici</translation>
    </message>
    <message>
        <source>Ensure that password contains characters from every group</source>
        <translation>Assicurati che la password contenga caratteri di ogni gruppo</translation>
    </message>
    <message>
        <source>Pronounceable</source>
        <translation>Pronunciabile</translation>
    </message>
    <message>
        <source>Lower Letters</source>
        <translation>Lettere minuscole</translation>
    </message>
    <message>
        <source>Upper Letters</source>
        <translation>Lettere maiuscole</translation>
    </message>
    <message>
        <source>Numbers</source>
        <translation>Numeri</translation>
    </message>
    <message>
        <source>Special Characters</source>
        <translation>Caratteri speciali</translation>
    </message>
    <message>
        <source>Use following character groups:</source>
        <translation>Utilizza i seguenti gruppi di carattere:</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Personalizza</translation>
    </message>
    <message>
        <source>Use the following characters:</source>
        <translation>Utilizza i seguenti caratteri:</translation>
    </message>
</context>
<context>
    <name>HelpDlg</name>
    <message>
        <source>Previous Page</source>
        <translation>Pagina precedente</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Pagina successiva</translation>
    </message>
    <message>
        <source>First Page</source>
        <translation>Prima pagina</translation>
    </message>
    <message>
        <source>Help Contents</source>
        <translation>Contenuti guida</translation>
    </message>
</context>
<context>
    <name>Import_KWalletXml</name>
    <message>
        <source>XML Files (*.xml)</source>
        <translation>Files XML (*.xml)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Tutti i files (*)</translation>
    </message>
    <message>
        <source>Import Failed</source>
        <translation>Importazione fallita</translation>
    </message>
    <message>
        <source>Invalid XML data (see stdout for details).</source>
        <translation>Dati XML non validi (vedi stdout per dettagli).</translation>
    </message>
    <message>
        <source>Invalid XML file.</source>
        <translation>File XML non valido.</translation>
    </message>
    <message>
        <source>Document does not contain data.</source>
        <translation>Il documento non contiene dati.</translation>
    </message>
</context>
<context>
    <name>Import_KeePassX_Xml</name>
    <message>
        <source>KeePass XML Files (*.xml)</source>
        <translation>File XML KeePass (*.xml)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Tutti i files (*)</translation>
    </message>
    <message>
        <source>Import Failed</source>
        <translation>Importazione fallita</translation>
    </message>
    <message>
        <source>XML parsing error on line %1 column %2:
%3</source>
        <translation>Errore analisi XML nella riga %1 colonna %2:
%3</translation>
    </message>
    <message>
        <source>Parsing error: File is no valid KeePassX XML file.</source>
        <translation>Errore analisi: Il file non è un valido file XML di KeePassX.</translation>
    </message>
</context>
<context>
    <name>Import_PwManager</name>
    <message>
        <source>PwManager Files (*.pwm)</source>
        <translation>Files PwManager (*.pwm)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Tutti i files (*)</translation>
    </message>
    <message>
        <source>Import Failed</source>
        <translation>Importazione fallita</translation>
    </message>
    <message>
        <source>File is empty.</source>
        <translation>Il fIle è vuoto.</translation>
    </message>
    <message>
        <source>File is no valid PwManager file.</source>
        <translation>Il file non è un valido file PwManager.</translation>
    </message>
    <message>
        <source>Unsupported file version.</source>
        <translation>Versione file non supportata.</translation>
    </message>
    <message>
        <source>Unsupported hash algorithm.</source>
        <translation>Algoritmo di hash non supportato.</translation>
    </message>
    <message>
        <source>Unsupported encryption algorithm.</source>
        <translation>Algoritmo di cifratura non supportato.</translation>
    </message>
    <message>
        <source>Compressed files are not supported yet.</source>
        <translation>I file compressi non sono ancora supportati.</translation>
    </message>
    <message>
        <source>Wrong password.</source>
        <translation>Password errata.</translation>
    </message>
    <message>
        <source>File is damaged (hash test failed).</source>
        <translation>Il file è danneggiato (prova di hash fallita).</translation>
    </message>
    <message>
        <source>Invalid XML data (see stdout for details).</source>
        <translation>Dati XML non validi (vedi stdout per dettagli).</translation>
    </message>
</context>
<context>
    <name>ImporterBase</name>
    <message>
        <source>Import File...</source>
        <translation>Importa file...</translation>
    </message>
    <message>
        <source>Import Failed</source>
        <translation>Importazione fallita</translation>
    </message>
</context>
<context>
    <name>Kdb3Database</name>
    <message>
        <source>Could not open file.</source>
        <translation>Impossibile aprire il file.</translation>
    </message>
    <message>
        <source>Unexpected file size (DB_TOTAL_SIZE &lt; DB_HEADER_SIZE)</source>
        <translation>Dimensione file inattesa (DB_TOTAL_SIZE &lt; DB_HEADER_SIZE)</translation>
    </message>
    <message>
        <source>Wrong Signature</source>
        <translation>Firma errata</translation>
    </message>
    <message>
        <source>Unsupported File Version.</source>
        <translation>Versione file non supportata.</translation>
    </message>
    <message>
        <source>Unknown Encryption Algorithm.</source>
        <translation>Algoritmo di cifratura sconosciuto.</translation>
    </message>
    <message>
        <source>Unable to initialize the twofish algorithm.</source>
        <translation>Impossibile inizializzare l&apos;algoritmo twofish.</translation>
    </message>
    <message>
        <source>Unknown encryption algorithm.</source>
        <translation>Algoritmo di cifratura sconosciuto.</translation>
    </message>
    <message>
        <source>Decryption failed.
The key is wrong or the file is damaged.</source>
        <translation>Decifratura fallita.
La chiave è errata oppure il file è danneggiato.</translation>
    </message>
    <message>
        <source>Hash test failed.
The key is wrong or the file is damaged.</source>
        <translation>Prova di hash fallita.
La chiave è errata oppure il file è danneggiato.</translation>
    </message>
    <message>
        <source>Unexpected error: Offset is out of range.</source>
        <translation>Errore inatteso: La posizione è fuori campo.</translation>
    </message>
    <message>
        <source>Invalid group tree.</source>
        <translation>Albero del gruppo non valido.</translation>
    </message>
    <message>
        <source>Key file is empty.</source>
        <translation>Il fIle chiave è vuoto.</translation>
    </message>
    <message>
        <source>The database must contain at least one group.</source>
        <translation>Il database deve contenere almeno un gruppo.</translation>
    </message>
    <message>
        <source>Could not open file for writing.</source>
        <translation type="obsolete">Impossibile aprire il file per la scrittura.</translation>
    </message>
    <message>
        <source>Unable to initalize the twofish algorithm.</source>
        <translation type="obsolete">Impossibile inizializzare l&apos;algoritmo twofish.</translation>
    </message>
    <message>
        <source>The database has been opened read-only.</source>
        <translation>Il database è stato aperto in sola lettura.</translation>
    </message>
</context>
<context>
    <name>Kdb3Database::EntryHandle</name>
    <message>
        <source>Bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <source>KiB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MiB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>GiB</source>
        <translation>GB</translation>
    </message>
</context>
<context>
    <name>KeepassEntryView</name>
    <message>
        <source>Delete?</source>
        <translation>Eliminare?</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>At least one group must exist before adding an entry.</source>
        <translation>Deve esistere almeno un gruppo prima di aggiungere una voce.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome utente</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Comments</source>
        <translation>Commenti</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Scade</translation>
    </message>
    <message>
        <source>Creation</source>
        <translation>Creazione</translation>
    </message>
    <message>
        <source>Last Change</source>
        <translation>Ultima modifica</translation>
    </message>
    <message>
        <source>Last Access</source>
        <translation>Ultimo accesso</translation>
    </message>
    <message>
        <source>Attachment</source>
        <translation>Allegato</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Gruppo</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this entry?</source>
        <translation>Sei sicuro di voler eliminare questa voce?</translation>
    </message>
    <message>
        <source>Are you sure you want to delete these %1 entries?</source>
        <translation>Sei sicuro di voler eliminare queste %1 voci?</translation>
    </message>
</context>
<context>
    <name>KeepassGroupView</name>
    <message>
        <source>Search Results</source>
        <translation>Risultati della ricerca</translation>
    </message>
    <message>
        <source>Delete?</source>
        <translation>Eliminare?</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this group, all it&apos;s child groups and all their entries?</source>
        <translation type="obsolete">Sei sicuro di voler eliminare questo gruppo, tutti i suoi sottogruppi e le loro voci?</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this group, all its child groups and all their entries?</source>
        <translation>Sei sicuro di voler eliminare questo gruppo, tutti i suoi sottogruppi e le loro voci?</translation>
    </message>
</context>
<context>
    <name>KeepassMainWindow</name>
    <message>
        <source>Ready</source>
        <translation>Pronto</translation>
    </message>
    <message>
        <source>Locked</source>
        <translation type="obsolete">Bloccato</translation>
    </message>
    <message>
        <source>Unlocked</source>
        <translation type="obsolete">Sbloccato</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Shift+Ctrl+S</source>
        <translation>Shift+Ctrl+S</translation>
    </message>
    <message>
        <source>Shift+Ctrl+F</source>
        <translation>Shift+Ctrl+F</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>The database file does not exist.</source>
        <translation>Il file di database non esiste.</translation>
    </message>
    <message>
        <source>Loading Database...</source>
        <translation>Caricamento Database...</translation>
    </message>
    <message>
        <source>Loading Failed</source>
        <translation>Caricamento fallito</translation>
    </message>
    <message>
        <source>Unknown error while loading database.</source>
        <translation>Errore sconosciuto durante il caricamento del database.</translation>
    </message>
    <message>
        <source>The following error occured while opening the database:</source>
        <translation>Si è verificato il seguente errore durante l&apos;apertura del database:</translation>
    </message>
    <message>
        <source>Save modified file?</source>
        <translation>Salvare il file modificato?</translation>
    </message>
    <message>
        <source>The current file was modified. Do you want
to save the changes?</source>
        <translation type="obsolete">Il file attuale è stato modificato. Vuoi
salvare le modifiche?</translation>
    </message>
    <message>
        <source>new</source>
        <translation>nuovo</translation>
    </message>
    <message>
        <source>Open Database...</source>
        <translation>Apri Database...</translation>
    </message>
    <message>
        <source>KeePass Databases (*.kdb)</source>
        <translation>Database KeePass (*.kdb)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Tutti i files (*)</translation>
    </message>
    <message>
        <source>Expired</source>
        <translation>Scaduta</translation>
    </message>
    <message>
        <source>1 Month</source>
        <translation>1 Mese</translation>
    </message>
    <message>
        <source>%1 Months</source>
        <translation>%1 Mesi</translation>
    </message>
    <message>
        <source>1 Year</source>
        <translation>1 Anno</translation>
    </message>
    <message>
        <source>%1 Years</source>
        <translation>%1 Anni</translation>
    </message>
    <message>
        <source>1 Day</source>
        <translation>1 Giorno</translation>
    </message>
    <message>
        <source>%1 Days</source>
        <translation>%1 Giorni</translation>
    </message>
    <message>
        <source>less than 1 day</source>
        <translation>meno di 1 giorno</translation>
    </message>
    <message>
        <source>Clone Entry</source>
        <translation>Duplica voce</translation>
    </message>
    <message>
        <source>Delete Entry</source>
        <translation>Elimina voce</translation>
    </message>
    <message>
        <source>Clone Entries</source>
        <translation>Duplica voci</translation>
    </message>
    <message>
        <source>Delete Entries</source>
        <translation>Elimina voci</translation>
    </message>
    <message>
        <source>File could not be saved.</source>
        <translation>Impossibile salvare il file.</translation>
    </message>
    <message>
        <source>Save Database...</source>
        <translation>Salva Database...</translation>
    </message>
    <message>
        <source>Un&amp;lock Workspace</source>
        <translation>Sb&amp;locca l&apos;area di lavoro</translation>
    </message>
    <message>
        <source>&amp;Lock Workspace</source>
        <translation>&amp;Blocca l&apos;area di lavoro</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Mostra barra degli &amp;strumenti</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Database locked</source>
        <translation>Database bloccato</translation>
    </message>
    <message>
        <source>The database you are trying to open is locked.
This means that either someone else has opened the file or KeePassX crashed last time it opened the database.

Do you want to open it anyway?</source>
        <translation>Il database che stai tentando di aprire è bloccato.
Questo significa che qualcun altro ha aperto il file o che KeePassX si è bloccato l&apos;ultima volta che si è aperto il database.

Vuoi comunque aprirlo?</translation>
    </message>
    <message>
        <source>The current file was modified.
Do you want to save the changes?</source>
        <translation>Il file attuale è stato modificato. Vuoi salvare le modifiche?</translation>
    </message>
    <message>
        <source>Couldn&apos;t remove database lock file.</source>
        <translation>Impossibile rimuovere il file di blocco del database.</translation>
    </message>
    <message>
        <source>Open read-only</source>
        <translation>Apri in sola lettura</translation>
    </message>
    <message>
        <source>Couldn&apos;t create lock file. Opening the database read-only.</source>
        <translation>Impossibile creare il file di blocco. Apertura del database in sola lettura.</translation>
    </message>
    <message>
        <source>Couldn&apos;t create database lock file.</source>
        <translation>Impossibile creare il file di blocco del database.</translation>
    </message>
    <message>
        <source>locked</source>
        <translation>bloccato</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>File &apos;%1&apos; could not be found.</source>
        <translation>Impossibile trovare il file &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">OK</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>KeePassX</source>
        <translation>KeePassX</translation>
    </message>
    <message>
        <source>Groups</source>
        <translation>Gruppi</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Guida</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <source>&amp;Export to...</source>
        <translation>Esp&amp;orta in...</translation>
    </message>
    <message>
        <source>&amp;Import from...</source>
        <translation>Im&amp;porta da...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="obsolete">&amp;Modifica</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Visualizza</translation>
    </message>
    <message>
        <source>E&amp;xtras</source>
        <translation>&amp;Utilità</translation>
    </message>
    <message>
        <source>&amp;Open Database...</source>
        <translation>&amp;Apri Database...</translation>
    </message>
    <message>
        <source>&amp;Close Database</source>
        <translation>&amp;Chiudi Database</translation>
    </message>
    <message>
        <source>&amp;Save Database</source>
        <translation>&amp;Salva Database</translation>
    </message>
    <message>
        <source>Save Database &amp;As...</source>
        <translation>Save Database &amp;come...</translation>
    </message>
    <message>
        <source>&amp;Database Settings...</source>
        <translation>Impostazioni &amp;Database...</translation>
    </message>
    <message>
        <source>Change &amp;Master Key...</source>
        <translation>Cambia la chiave &amp;principale...</translation>
    </message>
    <message>
        <source>&amp;Lock Workspace</source>
        <translation>&amp;Blocca l&apos;area di lavoro</translation>
    </message>
    <message>
        <source>&amp;Settings...</source>
        <translation>&amp;Impostazioni...</translation>
    </message>
    <message>
        <source>&amp;About...</source>
        <translation>&amp;Informazioni su...</translation>
    </message>
    <message>
        <source>&amp;KeePassX Handbook...</source>
        <translation>Manuale &amp;KeePassX...</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Nascondi</translation>
    </message>
    <message>
        <source>Standard KeePass Single User Database (*.kdb)</source>
        <translation type="obsolete">Database KeePass standard a singolo utente (*.kdb)</translation>
    </message>
    <message>
        <source>Advanced KeePassX Database (*.kxdb)</source>
        <translation type="obsolete">Database KeePassX avanzato (*.kxdb)</translation>
    </message>
    <message>
        <source>Recycle Bin...</source>
        <translation>Cestino...</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Segnalibri</translation>
    </message>
    <message>
        <source>Toolbar &amp;Icon Size</source>
        <translation>Dimensione &amp;icona barra degli strumenti</translation>
    </message>
    <message>
        <source>&amp;Columns</source>
        <translation>&amp;Colonne</translation>
    </message>
    <message>
        <source>&amp;Manage Bookmarks...</source>
        <translation>Gestisci i Se&amp;gnalibri...</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>E&amp;sci</translation>
    </message>
    <message>
        <source>&amp;Add New Group...</source>
        <translation type="obsolete">&amp;Aggiungi nuovo gruppo...</translation>
    </message>
    <message>
        <source>&amp;Edit Group...</source>
        <translation>Modi&amp;fica gruppo...</translation>
    </message>
    <message>
        <source>&amp;Delete Group</source>
        <translation>Elimina &amp;gruppo</translation>
    </message>
    <message>
        <source>Copy Password &amp;to Clipboard</source>
        <translation>Copia la password negli &amp;Appunti</translation>
    </message>
    <message>
        <source>Copy &amp;Username to Clipboard</source>
        <translation>Copia il nome &amp;utente negli Appunti</translation>
    </message>
    <message>
        <source>&amp;Open URL</source>
        <translation>&amp;Apri URL</translation>
    </message>
    <message>
        <source>&amp;Save Attachment As...</source>
        <translation>&amp;Salva allegato come...</translation>
    </message>
    <message>
        <source>Add &amp;New Entry...</source>
        <translation>Aggiungi &amp;nuova voce...</translation>
    </message>
    <message>
        <source>&amp;View/Edit Entry...</source>
        <translation>&amp;Visualizza/Modifica voce...</translation>
    </message>
    <message>
        <source>De&amp;lete Entry</source>
        <translation>E&amp;limina voce</translation>
    </message>
    <message>
        <source>&amp;Clone Entry</source>
        <translation>&amp;Duplica voce</translation>
    </message>
    <message>
        <source>Search &amp;in Database...</source>
        <translation>Cerca &amp;nel Database...</translation>
    </message>
    <message>
        <source>Search in this &amp;Group...</source>
        <translation>Cerca in questo &amp;gruppo...</translation>
    </message>
    <message>
        <source>Show &amp;Entry Details</source>
        <translation>Mostra d&amp;ettagli voce</translation>
    </message>
    <message>
        <source>Hide &amp;Usernames</source>
        <translation>Nascondi nomi &amp;utente</translation>
    </message>
    <message>
        <source>Hide &amp;Passwords</source>
        <translation>Nascondi &amp;password</translation>
    </message>
    <message>
        <source>&amp;Title</source>
        <translation>&amp;Titolo</translation>
    </message>
    <message>
        <source>User&amp;name</source>
        <translation>&amp;Nome utente</translation>
    </message>
    <message>
        <source>&amp;URL</source>
        <translation>&amp;URL</translation>
    </message>
    <message>
        <source>&amp;Password</source>
        <translation>&amp;Password</translation>
    </message>
    <message>
        <source>&amp;Comment</source>
        <translation>&amp;Commento</translation>
    </message>
    <message>
        <source>E&amp;xpires</source>
        <translation>&amp;Scade</translation>
    </message>
    <message>
        <source>C&amp;reation</source>
        <translation>C&amp;reazione</translation>
    </message>
    <message>
        <source>&amp;Last Change</source>
        <translation>U&amp;ltima modifica</translation>
    </message>
    <message>
        <source>Last &amp;Access</source>
        <translation>Ultimo &amp;accesso</translation>
    </message>
    <message>
        <source>A&amp;ttachment</source>
        <translation>Allega&amp;to</translation>
    </message>
    <message>
        <source>Show &amp;Statusbar</source>
        <translation>Mostra la barra di &amp;stato</translation>
    </message>
    <message>
        <source>&amp;Perform AutoType</source>
        <translation>Esegui Auto &amp;Digitazione</translation>
    </message>
    <message>
        <source>&amp;16x16</source>
        <translation>&amp;16x16</translation>
    </message>
    <message>
        <source>&amp;22x22</source>
        <translation>&amp;22x22</translation>
    </message>
    <message>
        <source>2&amp;8x28</source>
        <translation>2&amp;8x28</translation>
    </message>
    <message>
        <source>&amp;New Database...</source>
        <translation>&amp;Nuovo Database...</translation>
    </message>
    <message>
        <source>&amp;Password Generator...</source>
        <translation>Generatore di &amp;password...</translation>
    </message>
    <message>
        <source>&amp;Group (search results only)</source>
        <translation type="obsolete">&amp;Gruppo (ricerca solo di risultati)</translation>
    </message>
    <message>
        <source>Show &amp;Expired Entries...</source>
        <translation>Mostra voci scadut&amp;e...</translation>
    </message>
    <message>
        <source>&amp;Add Bookmark...</source>
        <translation>&amp;Aggiungi ai Segnalibri...</translation>
    </message>
    <message>
        <source>Bookmark &amp;this Database...</source>
        <translation>Imposta il Database come &amp;Segnalibro...</translation>
    </message>
    <message>
        <source>&amp;Add New Subgroup...</source>
        <translation>&amp;Aggiungi nuovo sottogruppo...</translation>
    </message>
    <message>
        <source>Copy URL to Clipboard</source>
        <translation>Copia URL negli Appunti</translation>
    </message>
    <message>
        <source>Add New Group...</source>
        <translation>Aggiungi nuovo gruppo...</translation>
    </message>
    <message>
        <source>&amp;Entries</source>
        <translation>&amp;Voci</translation>
    </message>
    <message>
        <source>&amp;Groups</source>
        <translation>&amp;Gruppi</translation>
    </message>
    <message>
        <source>Sort groups</source>
        <translation>Ordina gruppi</translation>
    </message>
    <message>
        <source>&amp;Group</source>
        <translation>&amp;Gruppo</translation>
    </message>
    <message>
        <source>&amp;Minimize Window</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ManageBookmarksDlg</name>
    <message>
        <source>Manage Bookmarks</source>
        <translation>Gestisci Segnalibri</translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Enter Master Key</source>
        <translation>Inserisci la chiave principale</translation>
    </message>
    <message>
        <source>Set Master Key</source>
        <translation>Imposta la chiave principale</translation>
    </message>
    <message>
        <source>Change Master Key</source>
        <translation>Cambia chiave principale</translation>
    </message>
    <message>
        <source>Database Key</source>
        <translation>Chiave Database</translation>
    </message>
    <message>
        <source>Last File</source>
        <translation>Ultimo file</translation>
    </message>
    <message>
        <source>Select a Key File</source>
        <translation>Seleziona un file chiave</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Tutti i files (*)</translation>
    </message>
    <message>
        <source>Key Files (*.key)</source>
        <translation>File chiave (*.key)</translation>
    </message>
    <message>
        <source>Please enter a Password or select a key file.</source>
        <translation>Inserisci una password o seleziona un file chiave.</translation>
    </message>
    <message>
        <source>Please enter a Password.</source>
        <translation>Insersci una password.</translation>
    </message>
    <message>
        <source>Please provide a key file.</source>
        <translation>Fornisci un file chiave.</translation>
    </message>
    <message>
        <source>%1:
No such file or directory.</source>
        <translation>%1:
Nessun file o directory.</translation>
    </message>
    <message>
        <source>The selected key file or directory is not readable.</source>
        <translation>Il file chiave o la directory selezionata non è leggibile.</translation>
    </message>
    <message>
        <source>The given directory does not contain any key files.</source>
        <translation>La directory selezionata non contiene alcun file chiave.</translation>
    </message>
    <message>
        <source>The given directory contains more then one key files.
Please specify the key file directly.</source>
        <translation>La directory selezionata contiene più di un file chiave.
Specifica il file chiave direttamente.</translation>
    </message>
    <message>
        <source>%1:
File is not readable.</source>
        <translation>%1:
Il file non è leggibile.</translation>
    </message>
    <message>
        <source>Create Key File...</source>
        <translation>Crea un file chiave...</translation>
    </message>
</context>
<context>
    <name>PasswordDlg</name>
    <message>
        <source>Last File</source>
        <translation>Ultimo file</translation>
    </message>
    <message>
        <source>Enter a Password and/or choose a key file.</source>
        <translation>Inserisci la password e/o seleziona il file chiave.</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Chiave</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Password:</translation>
    </message>
    <message>
        <source>&amp;Browse...</source>
        <translation>&amp;Sfoglia...</translation>
    </message>
    <message>
        <source>Alt+B</source>
        <translation type="obsolete">Alt+S</translation>
    </message>
    <message>
        <source>Key File:</source>
        <translation>File chiave:</translation>
    </message>
    <message>
        <source>Generate Key File...</source>
        <translation>Genera file chiave...</translation>
    </message>
    <message>
        <source>Please repeat your password:</source>
        <translation>Ripeti la password:</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
    <message>
        <source>Passwords are not equal.</source>
        <translation>Le password non corrispondono.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Could not locate library file.</source>
        <translation type="obsolete">Impossibile trovare il file di libreria.</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
</context>
<context>
    <name>Search_Dlg</name>
    <message>
        <source>Search...</source>
        <translation>Cerca...</translation>
    </message>
    <message>
        <source>Include:</source>
        <translation>Includi:</translation>
    </message>
    <message>
        <source>Pass&amp;words</source>
        <translation>Pass&amp;words</translation>
    </message>
    <message>
        <source>Alt+W</source>
        <translation type="obsolete">Alt+W</translation>
    </message>
    <message>
        <source>A&amp;nhang</source>
        <translation>A&amp;nhang</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="obsolete">Alt+N</translation>
    </message>
    <message>
        <source>U&amp;RLs</source>
        <translation>U&amp;RL</translation>
    </message>
    <message>
        <source>Alt+R</source>
        <translation type="obsolete">Alt+R</translation>
    </message>
    <message>
        <source>C&amp;omments</source>
        <translation>C&amp;ommenti</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="obsolete">Alt+O</translation>
    </message>
    <message>
        <source>&amp;Usernames</source>
        <translation>Nomi &amp;Utente</translation>
    </message>
    <message>
        <source>Alt+U</source>
        <translation type="obsolete">Alt+U</translation>
    </message>
    <message>
        <source>&amp;Titles</source>
        <translation>&amp;Titoli</translation>
    </message>
    <message>
        <source>Alt+T</source>
        <translation type="obsolete">Alt+T</translation>
    </message>
    <message>
        <source>&amp;Case Sensitive</source>
        <translation>&amp;Case Sensitive</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+C</translation>
    </message>
    <message>
        <source>Regular E&amp;xpression</source>
        <translation>&amp;Espressione regolare</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation type="obsolete">Alt+E</translation>
    </message>
    <message>
        <source>Include Subgroups (recursive)</source>
        <translation>Includi sottogruppi (ricorsivo)</translation>
    </message>
    <message>
        <source>Search For:</source>
        <translation>Cerca per:</translation>
    </message>
</context>
<context>
    <name>SelectIconDlg</name>
    <message>
        <source>Icon Selection</source>
        <translation>Selezione icona</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <source>The integration plugins provide features like usage of the native file dialogs and message boxes of the particular desktop environments.</source>
        <translation type="obsolete">L&apos;integrazione dei plugins fornisce caratteristiche come l&apos;uso di file di finestre di dialogo nativi e caselle messaggi degli ambienti desktop particolari.</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="obsolete">Generale</translation>
    </message>
    <message>
        <source>Show system tray icon</source>
        <translation>Mostra icona nella barra di sistema</translation>
    </message>
    <message>
        <source>Minimize to tray instead of taskbar</source>
        <translation>Riduci a icona nella barra di sistema anzichè nella barra delle applicazioni</translation>
    </message>
    <message>
        <source>Minimize to tray when clicking the main window&apos;s close button</source>
        <translation type="unfinished">Riduci alla barra di sistema al click del pulsante chiudi della finestra principale</translation>
    </message>
    <message>
        <source>Remember last opened file</source>
        <translation>Ricorda l&apos;ultimo file aperto</translation>
    </message>
    <message utf8="true">
        <source>Alt+Ö</source>
        <translation type="obsolete">Alt+Ö</translation>
    </message>
    <message>
        <source>Remember last key type and location</source>
        <translation>Ricorda l&apos;ultima chiave digitata e la posizione</translation>
    </message>
    <message>
        <source>Start minimized</source>
        <translation>Avvia ridotto a icona</translation>
    </message>
    <message>
        <source>Start locked</source>
        <translation>Avvia bloccato</translation>
    </message>
    <message>
        <source>Save recent directories of file dialogs</source>
        <translation>Salva directory recenti dei file di dialoghi</translation>
    </message>
    <message>
        <source>Clear History Now</source>
        <translation>Pulisci ora la cronologia </translation>
    </message>
    <message>
        <source>Always ask before deleting entries or groups</source>
        <translation>Chiedi sempre prima di eliminare voci o gruppi</translation>
    </message>
    <message>
        <source>Appea&amp;rance</source>
        <translation type="obsolete">Asp&amp;etto</translation>
    </message>
    <message>
        <source>Banner Color</source>
        <translation>Colore banner</translation>
    </message>
    <message>
        <source>Text Color:</source>
        <translation>Colore testo:</translation>
    </message>
    <message>
        <source>Change...</source>
        <translation>Cambia...</translation>
    </message>
    <message>
        <source>Color 2:</source>
        <translation>Colore 2:</translation>
    </message>
    <message>
        <source>C&amp;hange...</source>
        <translation>Ca&amp;mbia...</translation>
    </message>
    <message>
        <source>Alt+H</source>
        <translation type="obsolete">Alt+M</translation>
    </message>
    <message>
        <source>Color 1:</source>
        <translation>Colore 1:</translation>
    </message>
    <message>
        <source>Alternating Row Colors</source>
        <translation>Colore alternativo delle righe</translation>
    </message>
    <message>
        <source>Customize Entry Detail View...</source>
        <translation>Personalizza la voce Visualizza dettagli...</translation>
    </message>
    <message>
        <source>Group tree at start-up:</source>
        <translation>Albero del gruppo all&apos;avvio:</translation>
    </message>
    <message>
        <source>Restore last state</source>
        <translation>Ripristina ultimo stato</translation>
    </message>
    <message>
        <source>Expand all items</source>
        <translation>Espandi tutti i valori</translation>
    </message>
    <message>
        <source>Do not expand any item</source>
        <translation>Non espandere alcun valore</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Sicurezza</translation>
    </message>
    <message>
        <source>Edit Entry Dialog</source>
        <translation>Modifica finestra di dialogo della voce</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="obsolete">Alt+O</translation>
    </message>
    <message>
        <source>Clear clipboard after:</source>
        <translation>Pulisci gli Appunti dopo:</translation>
    </message>
    <message>
        <source>Lock workspace when minimizing the main window</source>
        <translation>Blocca l&apos;area di lavoro quando riduci a icona la finestra principale</translation>
    </message>
    <message>
        <source>Features</source>
        <translation type="obsolete">Caratteristiche</translation>
    </message>
    <message>
        <source>You can disable several features of KeePassX here according to your needs in order to keep the user interface slim.</source>
        <translation>Qui puoi disabilitare alcune caratteristiche di KeePassX a seconda delle tue necessità in modo da mantenere snella l&apos;interfaccia utente.</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Segnalibri</translation>
    </message>
    <message>
        <source>Desktop Integration</source>
        <translation type="obsolete">Integrazione con il Desktop</translation>
    </message>
    <message>
        <source>Plug-Ins</source>
        <translation>Plug-Ins</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nessuno</translation>
    </message>
    <message>
        <source>Gnome Desktop Integration (Gtk 2.x)</source>
        <translation>Integrazione con il Desktop di Gnome (Gtk 2.x)</translation>
    </message>
    <message>
        <source>KDE 4 Desktop Integration</source>
        <translation>Integrazione con il Desktop di KDE 4</translation>
    </message>
    <message>
        <source>You need to restart the program before the changes take effect.</source>
        <translation>Devi riavviare il programma per rendere effettivi i cambiamenti.</translation>
    </message>
    <message>
        <source>Configure...</source>
        <translation>Configura...</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avanzate</translation>
    </message>
    <message>
        <source>Auto-Type Fine Tuning</source>
        <translation>Regola in modo fine l&apos;Auto Digitazione</translation>
    </message>
    <message>
        <source>Time between the activation of an auto-type action by the user and the first simulated key stroke.</source>
        <translation>Tempo tra l&apos;attivazione di un&apos;azione da parte dell&apos;utente di Auto Digitazione e la pressione della prima chiave simulata.</translation>
    </message>
    <message>
        <source>ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <source>Pre-Gap:</source>
        <translation>Differenza precedente:</translation>
    </message>
    <message>
        <source>Key Stroke Delay:</source>
        <translation>Ritardo pressione tasti:</translation>
    </message>
    <message>
        <source>Delay between two simulated key strokes. Increase this if Auto-Type is randomly skipping characters.</source>
        <translation>Ritardo tra due pressioni dei tasti simulati. Aumentalo se l&apos;Auto Digitazione salta casualmente i caratteri.</translation>
    </message>
    <message>
        <source>Custom Browser Command</source>
        <translation>Personalizza il comando Sfoglia</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Sfoglia</translation>
    </message>
    <message>
        <source>Media Root:</source>
        <translation>Radice dei media:</translation>
    </message>
    <message>
        <source>The directory where storage devices like CDs and memory sticks are normally mounted.</source>
        <translation>La directory dove le periferiche di salvataggio come CD e chiavette USB vengono montate di solito.</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Sfoglia...</translation>
    </message>
    <message>
        <source>Enable this if you want to use your bookmarks and the last opened file independet from their absolute paths. This is especially useful when using KeePassX portably and therefore with changing mount points in the file system.</source>
        <translation>Abilita questo se vuoi usare i segnalibri e l&apos;ultimo file aperto indipendentemente dai loro percorsi assoluti. Questo è utile specialmente quando si usa KeePassX in modo portatile e perciò i punti di mount cambiano nel file system.</translation>
    </message>
    <message>
        <source>Save relative paths (bookmarks and last file)</source>
        <translation>Salva i percorsi relativi (segnalibri e ultimo file)</translation>
    </message>
    <message>
        <source>Global Auto-Type Shortcut:</source>
        <translation>Collegamento Auto Digitazione globale:</translation>
    </message>
    <message>
        <source>Automatically save database on exit and workspace locking</source>
        <translation>Salva automaticamente il database all&apos;uscita e blocca l&apos;area di lavoro</translation>
    </message>
    <message>
        <source>Show plain text passwords in:</source>
        <translation>Mostra password in chiaro in:</translation>
    </message>
    <message>
        <source>Database Key Dialog</source>
        <translation>Finestra chiave database</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>secondi</translation>
    </message>
    <message>
        <source>Lock database after inactivity of</source>
        <translation>Blocca il database dopo inattività di</translation>
    </message>
    <message>
        <source>Use entries&apos; title to match the window for Global Auto-Type</source>
        <translation>Utilizza i titoli della voce per far corrispondere la finestra di Auto Digitazione Globale</translation>
    </message>
    <message>
        <source>General (1)</source>
        <translation>Generale (1)</translation>
    </message>
    <message>
        <source>General (2)</source>
        <translation>Generale (2)</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Aspetto</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Lingua</translation>
    </message>
    <message>
        <source>Save backups of modified entries into the &apos;Backup&apos; group</source>
        <translation>Salva backup delle voci modificate nel gruppo &apos;Backup&apos;</translation>
    </message>
    <message>
        <source>Delete backup entries older than:</source>
        <translation>Elimina le voci di backup più vecchie di:</translation>
    </message>
    <message>
        <source>days</source>
        <translation>giorni</translation>
    </message>
    <message>
        <source>Automatically save database after every change</source>
        <translation>Salva automaticamente il database dopo ogni modifica</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Lingua:</translation>
    </message>
    <message>
        <source>Author:</source>
        <translation>Autore:</translation>
    </message>
    <message>
        <source>Show window always on top</source>
        <translation>Mostra finestra sempre in primo piano</translation>
    </message>
</context>
<context>
    <name>ShortcutWidget</name>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>AltGr</source>
        <translation>AltGr</translation>
    </message>
    <message>
        <source>Win</source>
        <translation>Win</translation>
    </message>
</context>
<context>
    <name>SimplePasswordDialog</name>
    <message>
        <source>Enter your Password</source>
        <translation>Inserisci la Password</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Password:</translation>
    </message>
</context>
<context>
    <name>TargetWindowDlg</name>
    <message>
        <source>Auto-Type: Select Target Window</source>
        <translation>Auto Digitazione: seleziona la finestra da usare</translation>
    </message>
    <message>
        <source>To specify the target window, either select an existing currently-opened window
from the drop-down list, or enter the window title manually:</source>
        <translation>Per specificare la finestra da usare, o selezioni una finestra attualmente aperta
dal menu a tendina, oppure inserisci il titolo della finestra manualmente:</translation>
    </message>
</context>
<context>
    <name>Translation</name>
    <message>
        <source>$TRANSLATION_AUTHOR</source>
        <translation>Diego Pierotto</translation>
    </message>
    <message>
        <source>$TRANSLATION_AUTHOR_EMAIL</source>
        <comment>Here you can enter your email or homepage if you want.</comment>
        <translation>ita.translations@tiscali.it</translation>
    </message>
    <message>
        <source>$LANGUAGE_NAME</source>
        <comment>Insert your language name in the format: English (United States)</comment>
        <translation>Italiano (Italia)</translation>
    </message>
</context>
<context>
    <name>WorkspaceLockedWidget</name>
    <message>
        <source>Form</source>
        <translation>Casella</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Verdana&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt; font-weight:600;&quot;&gt;The workspace is locked.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Verdana&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt; font-weight:600;&quot;&gt;L&apos;area di lavoro è bloccata.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Unlock</source>
        <translation>Sblocca</translation>
    </message>
    <message>
        <source>Close Database</source>
        <translation>Chiudi Database</translation>
    </message>
</context>
</TS>
